@@ -1,6 +1,6 @@
 /*******************************************************************************
  * @license
- * Copyright (c) 2010, 2016 IBM Corporation and others.
+ * Copyright (c) 2010, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License v1.0
  * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution
@@ -46,7 +46,11 @@ define([
 	'orion/commonPreferences',
 	'embeddedEditor/helper/memoryFileSysConst',
 	'orion/objects',
-	'orion/formatter'	
+	'orion/formatter',
+	'orion/lsp/languageServerRegistry',
+	'orion/lsp/utils',
+	'orion/gotoDefinition',
+	'orion/references'
 ], function(
 	messages,
 	mEditor, mEventTarget, mTextView, mTextModelFactory, mEditorFeatures, mHoverFactory, mContentAssist,
@@ -55,7 +59,8 @@ define([
 	mDispatcher, EditorContext, Highlight,
 	mMarkOccurrences, mSyntaxchecker, LiveEditSession,
 	mProblems, mBlamer, mDiffer,
-	mKeyBinding, util, Deferred, mContextMenu, mMetrics, mCommonPreferences, memoryFileSysConst, objects, mFormatter
+	mKeyBinding, util, Deferred, mContextMenu, mMetrics, mCommonPreferences, memoryFileSysConst, objects, mFormatter, mLanguageServerRegistry, Utils,
+	mGotoDefinition, mReferences
 ) {
 	var inMemoryFilePattern = memoryFileSysConst.MEMORY_FILE_PATTERN;
 	var Dispatcher = mDispatcher.Dispatcher;
@@ -319,8 +324,22 @@ define([
 			var progress = this.progress;
 			var contentTypeRegistry = this.contentTypeRegistry;
 			var editorCommands = this.editorCommands;
+			var languageServerRegistry = new mLanguageServerRegistry.LanguageServerRegistry(serviceRegistry, this.problemsServiceID);
 
-			var textViewFactory = function() {
+			var openedDocument;
+			function openDocument(evnt, languageServer) {
+				if (openedDocument) {
+					languageServer.didClose(openedDocument.location);
+				}
+				var metaData = inputManager.getFileMetadata();
+				openedDocument = {
+					location: metaData.Location,
+					version:  1
+				};
+				languageServer.didOpen(metaData.Location, inputManager.getContentType().id, openedDocument.version, evnt.text);
+			}
+
+			var textViewFactory = function(editor) {
 				var options = that.updateViewOptions(that.settings);
 				objects.mixin(options, {
 					parent: that._parent,
@@ -328,6 +347,25 @@ define([
 					wrappable: true
 				});
 				var textView = new mTextView.TextView(options);
+				textView.addEventListener("ModelChanging", function(evnt) {
+					var languageServer = languageServerRegistry.getServerByContentType(inputManager.getContentType());
+					if (!languageServer) {
+						return;
+					}
+					if (that.inputChanged) {
+						delete that.inputChanged;
+						openDocument(evnt, languageServer);
+						return;
+					}
+					if (!evnt.start) return;
+					var change = {
+						range: Utils.getRange(editor, evnt.start, evnt.start),
+						rangeLength: evnt.removedCharCount,
+						text: evnt.text
+					};
+					var metaData = inputManager.getFileMetadata();
+					languageServer.didChange(metaData.Location, openedDocument.version++, [change]);
+				});
 				return textView;
 			};
 
@@ -405,8 +443,13 @@ define([
 						}
 						return null;
 					}).filter(function(providerInfo) {
-						return !!providerInfo;
+						return Boolean(providerInfo);
 					});
+					// check lsp implementation for the current content type
+					var lspServer = languageServerRegistry.getServerByContentType(fileContentType);
+					if (lspServer) {
+						providerInfoArray.push({provider: lspServer, id: lspServer._id, lspServer: true, excludedStyles: "(string.*)"});
+					}
 				}
 
 				// Produce a bound EditorContext that contentAssist can invoke with no knowledge of ServiceRegistry.
@@ -451,7 +494,7 @@ define([
 				foldingRulerFactory: new mEditorFeatures.FoldingRulerFactory(),
 				zoomRulerFactory: new mEditorFeatures.ZoomRulerFactory(),
 				lineNumberRulerFactory: new mEditorFeatures.LineNumberRulerFactory(),
-				hoverFactory: new mHoverFactory.HoverFactory(serviceRegistry, inputManager, commandRegistry),
+				hoverFactory: new mHoverFactory.HoverFactory(serviceRegistry, inputManager, commandRegistry, languageServerRegistry),
 				contentAssistFactory: contentAssistFactory,
 				keyBindingFactory: keyBindingFactory,
 				statusReporter: this.statusReporter,
@@ -482,10 +525,20 @@ define([
 				}
 			});
 			inputManager.addEventListener("InputChanged", function(evnt) {
+				that.inputChanged = true;
 				that.createSession(evnt);
 				var textView = editor.getTextView();
 				if (textView) {
-					liveEditSession.start(inputManager.getContentType(), evnt.title);
+					var contentType = inputManager.getContentType();
+					var languageServer = languageServerRegistry.getServerByContentType(contentType);
+					if (languageServer) {
+						languageServer.start().then(function() {
+							if (this.renderToolbars) {
+								this.renderToolbars(inputManager.getFileMetadata());
+							}
+						}.bind(this));
+					}
+					liveEditSession.start(contentType, evnt.title);
 					textView.setOptions(this.updateViewOptions(this.settings));
 					this.markOccurrences.setOccurrencesVisible(this.settings.showOccurrences);
 					this.syntaxHighlighter.setup(evnt.contentType, editor.getTextView(), editor.getAnnotationModel(), evnt.title, true).then(function() {
@@ -510,11 +563,18 @@ define([
 				if(textView && textView.onSaving) {
 					textView.onSaving({type:evnt.type});
 				}
-			});
+				// get the lsp service matching the current content type
+				var lspLanguageServer = languageServerRegistry.getServerByContentType(inputManager.getContentType());
+				if (lspLanguageServer) {
+					lspLanguageServer.didSave(evnt.inputManager.getLocation());
+				}
+			}.bind(this));
 
 			this.blamer = new mBlamer.Blamer(serviceRegistry, inputManager, editor);
 			this.differ = new mDiffer.Differ(serviceRegistry, inputManager, editor);
-			this.formatter = new mFormatter.Formatter(serviceRegistry, inputManager, editor);
+			this.formatter = new mFormatter.Formatter(serviceRegistry, inputManager, editor, languageServerRegistry);
+			this.gotoDefinition = new mGotoDefinition.GotoDefinition(serviceRegistry, inputManager, editor, languageServerRegistry);
+			this.references = new mReferences.References(serviceRegistry, inputManager, editor, languageServerRegistry);
 
 			this.problemService = new mProblems.ProblemService(serviceRegistry, this.problemsServiceID);
 			var markerService = serviceRegistry.getService(this.problemsServiceID);
@@ -524,7 +584,7 @@ define([
 				});
 			}
 
-			var markOccurrences = this.markOccurrences = new mMarkOccurrences.MarkOccurrences(serviceRegistry, inputManager, editor);
+			var markOccurrences = this.markOccurrences = new mMarkOccurrences.MarkOccurrences(serviceRegistry, inputManager, editor, languageServerRegistry);
 			markOccurrences.setOccurrencesVisible(this.settings.showOccurrences);
 			markOccurrences.findOccurrences();
 			
@@ -544,10 +604,19 @@ define([
 			}
 			this.refreshSyntaxCheck = function() {
 				syntaxCheck(inputManager.getInput());
-			}
+			};
 			editor.addEventListener("InputChanged", function(evt) {
 				syntaxCheck(evt.title, evt.message, evt.contents);
 			});
+			var serviceListener = function(evnt) {
+				var textView = editor.getTextView();
+				if (textView) {
+					var contentAssist = new mContentAssist.ContentAssist(textView, serviceRegistry);
+					setContentAssistProviders(editor, contentAssist, evnt);
+				}
+			};
+			serviceRegistry.addEventListener("registered", serviceListener);
+			serviceRegistry.addEventListener("unregistering", serviceListener);
 
 			var contextImpl = Object.create(null);
 			[
@@ -627,7 +696,7 @@ define([
 			}
 			return styleAccessor;
 		},
-		_createContextMenu: function() {			
+		_createContextMenu: function() {
 			// Create the context menu element (TBD: re0use a single Node for all context Menus ??)
 			this._editorContextMenuNode = document.createElement("ul"); //$NON-NLS-0$
 			this._editorContextMenuNode.className = "dropdownMenu"; //$NON-NLS-0$
